==> qtjambi-webenginecore-5.15.9-sources.jar: io/qt/webengine/core/QWebEngineNotification.java <==
package io.qt.webengine.core;


/**
 * <p>Encapsulates the data of an HTML5 web notification</p>
 * <p>Java wrapper for Qt class <a href="http://doc.qt.io/qt-5/qwebenginenotification.html">QWebEngineNotification</a></p>
 */
public final class QWebEngineNotification extends io.qt.core.QObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QWebEngineNotification.class);
    

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qwebenginenotification.html#closed">QWebEngineNotification::closed()</a></p>
     */
    public final Signal0 closed = new Signal0();
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qwebenginenotification.html#click">QWebEngineNotification::click()const</a></p>
     */
    public final void click(){
        click_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    private native void click_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qwebenginenotification.html#close">QWebEngineNotification::close()const</a></p>
     */
    public final void close(){
        close_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    private native void close_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qwebenginenotification.html#direction-prop">QWebEngineNotification::direction()const</a></p>
     */
    @io.qt.QtPropertyReader(name="direction")
    @io.qt.QtPropertyConstant
    @io.qt.QtUninvokable
    public final io.qt.core.Qt.LayoutDirection direction(){
        return io.qt.core.Qt.LayoutDirection.resolve(direction_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this)));
    }
    
    @io.qt.QtUninvokable
    private native int direction_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qwebenginenotification.html#icon">QWebEngineNotification::icon()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.gui.QImage icon(){
        return icon_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.gui.QImage icon_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qwebenginenotification.html#language-prop">QWebEngineNotification::language()const</a></p>
     */
    @io.qt.QtPropertyReader(name="language")
    @io.qt.QtPropertyConstant
    @io.qt.QtUninvokable
    public final java.lang.String language(){
        return language_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String language_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qwebenginenotification.html#matches">QWebEngineNotification::matches(const QWebEngineNotification*)const</a></p>
     */
    @io.qt.QtUninvokable
    public final boolean matches(io.qt.webengine.core.QWebEngineNotification other){
        return matches_native_const_QWebEngineNotification_ptr_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(other));
    }
    
    @io.qt.QtUninvokable
    private native boolean matches_native_const_QWebEngineNotification_ptr_constfct(long __this__nativeId, long other);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qwebenginenotification.html#message-prop">QWebEngineNotification::message()const</a></p>
     */
    @io.qt.QtPropertyReader(name="message")
    @io.qt.QtPropertyConstant
    @io.qt.QtUninvokable
    public final java.lang.String message(){
        return message_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String message_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qwebenginenotification.html#origin-prop">QWebEngineNotification::origin()const</a></p>
     */
    @io.qt.QtPropertyReader(name="origin")
    @io.qt.QtPropertyConstant
    @io.qt.QtUninvokable
    public final io.qt.core.QUrl origin(){
        return origin_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QUrl origin_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qwebenginenotification.html#show">QWebEngineNotification::show()const</a></p>
     */
    public final void show(){
        show_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    private native void show_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qwebenginenotification.html#tag-prop">QWebEngineNotification::tag()const</a></p>
     */
    @io.qt.QtPropertyReader(name="tag")
    @io.qt.QtPropertyConstant
    @io.qt.QtUninvokable
    public final java.lang.String tag(){
        return tag_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String tag_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qwebenginenotification.html#title-prop">QWebEngineNotification::title()const</a></p>
     */
    @io.qt.QtPropertyReader(name="title")
    @io.qt.QtPropertyConstant
    @io.qt.QtUninvokable
    public final java.lang.String title(){
        return title_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String title_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QWebEngineNotification(QPrivateConstructor p) { super(p); } 
    
}

==> qtjambi-webenginecore-5.15.10-sources.jar: io/qt/webengine/core/QWebEngineNotification.java <==
package io.qt.webengine.core;


/**
 * <p>Encapsulates the data of an HTML5 web notification</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qwebenginenotification.html">QWebEngineNotification</a></p>
 */
public final class QWebEngineNotification extends io.qt.core.QObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QWebEngineNotification.class);
    

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qwebenginenotification.html#closed">QWebEngineNotification::closed()</a></p>
     */
    public final Signal0 closed = new Signal0();
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qwebenginenotification.html#click">QWebEngineNotification::click()const</a></p>
     */
    public final void click(){
        click_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    private native void click_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qwebenginenotification.html#close">QWebEngineNotification::close()const</a></p>
     */
    public final void close(){
        close_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    private native void close_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qwebenginenotification.html#direction-prop">QWebEngineNotification::direction()const</a></p>
     */
    @io.qt.QtPropertyReader(name="direction")
    @io.qt.QtPropertyConstant
    @io.qt.QtUninvokable
    public final io.qt.core.Qt.LayoutDirection direction(){
        return io.qt.core.Qt.LayoutDirection.resolve(direction_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this)));
    }
    
    @io.qt.QtUninvokable
    private native int direction_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qwebenginenotification.html#icon">QWebEngineNotification::icon()const</a></p>
     */
    @io.qt.QtUninvokable
    public final io.qt.gui.QImage icon(){
        return icon_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.gui.QImage icon_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qwebenginenotification.html#language-prop">QWebEngineNotification::language()const</a></p>
     */
    @io.qt.QtPropertyReader(name="language")
    @io.qt.QtPropertyConstant
    @io.qt.QtUninvokable
    public final java.lang.String language(){
        return language_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String language_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qwebenginenotification.html#matches">QWebEngineNotification::matches(const QWebEngineNotification*)const</a></p>
     */
    @io.qt.QtUninvokable
    public final boolean matches(io.qt.webengine.core.QWebEngineNotification other){
        return matches_native_const_QWebEngineNotification_ptr_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(other));
    }
    
    @io.qt.QtUninvokable
    private native boolean matches_native_const_QWebEngineNotification_ptr_constfct(long __this__nativeId, long other);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qwebenginenotification.html#message-prop">QWebEngineNotification::message()const</a></p>
     */
    @io.qt.QtPropertyReader(name="message")
    @io.qt.QtPropertyConstant
    @io.qt.QtUninvokable
    public final java.lang.String message(){
        return message_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String message_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qwebenginenotification.html#origin-prop">QWebEngineNotification::origin()const</a></p>
     */
    @io.qt.QtPropertyReader(name="origin")
    @io.qt.QtPropertyConstant
    @io.qt.QtUninvokable
    public final io.qt.core.QUrl origin(){
        return origin_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.core.QUrl origin_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qwebenginenotification.html#show">QWebEngineNotification::show()const</a></p>
     */
    public final void show(){
        show_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    private native void show_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qwebenginenotification.html#tag-prop">QWebEngineNotification::tag()const</a></p>
     */
    @io.qt.QtPropertyReader(name="tag")
    @io.qt.QtPropertyConstant
    @io.qt.QtUninvokable
    public final java.lang.String tag(){
        return tag_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String tag_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qwebenginenotification.html#title-prop">QWebEngineNotification::title()const</a></p>
     */
    @io.qt.QtPropertyReader(name="title")
    @io.qt.QtPropertyConstant
    @io.qt.QtUninvokable
    public final java.lang.String title(){
        return title_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String title_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QWebEngineNotification(QPrivateConstructor p) { super(p); } 
    
}
